#
# spec file for package audacious-plugins
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __provides_exclude_from ^%{_libdir}/audacious/*/.*.so$
%define aud_ver_min 4.3
%define aud_ver_max 4.3.99
%bcond_with faad
Name:           audacious-plugins
Version:        4.3
Release:        1.4
Summary:        Plugins for Audacious
License:        BSD-2-Clause AND GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-only AND MIT
URL:            https://audacious-media-player.org/
Source:         https://distfiles.audacious-media-player.org/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE fix-linking-mpg123.patch boo#1187525
Patch0:         fix-linking-mpg123.patch
# PATCH-FIX-UPSTREAM audacious-plugins-fix-qt6-qthotkey.patch sor.alexei@meowr.ru -- Fix Qt6 support in qthotkey.
Patch1:         audacious-plugins-fix-qt6-qthotkey.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libmp3lame-devel
BuildRequires:  lirc-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  sndio-devel
BuildRequires:  pkgconfig(alsa) >= 1.0.16
BuildRequires:  pkgconfig(audacious) >= %{aud_ver_min}
BuildRequires:  pkgconfig(flac) >= 1.2.1
BuildRequires:  pkgconfig(fluidsynth) >= 1.0.6
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(jack) >= 1.9.7
BuildRequires:  pkgconfig(libavcodec) >= 53.40.0
BuildRequires:  pkgconfig(libavformat) >= 53.25.0
BuildRequires:  pkgconfig(libavutil) >= 51.27.0
BuildRequires:  pkgconfig(libbs2b) >= 3.0.0
BuildRequires:  pkgconfig(libcddb) >= 1.2.1
BuildRequires:  pkgconfig(libcdio) >= 0.70
BuildRequires:  pkgconfig(libcdio_cdda) >= 0.70
BuildRequires:  pkgconfig(libcue)
BuildRequires:  pkgconfig(libcurl) >= 7.9.7
BuildRequires:  pkgconfig(libmms) >= 0.3
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libmpg123) >= 1.12
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libopenmpt)
BuildRequires:  pkgconfig(libpulse) >= 0.9.5
BuildRequires:  pkgconfig(libsidplayfp) >= 2.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(neon) >= 0.27
BuildRequires:  pkgconfig(ogg) >= 1.0
BuildRequires:  pkgconfig(opus) >= 1.0.1
BuildRequires:  pkgconfig(opusfile) >= 0.4
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl2) >= 2.0
BuildRequires:  pkgconfig(sndfile) >= 0.19
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile) >= 1.0
BuildRequires:  pkgconfig(wavpack) >= 4.31
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(zlib)
Requires:       libaudcore%{?_isa} <= %{aud_ver_max}
Requires:       libaudcore%{?_isa} >= %{aud_ver_min}
Recommends:     %{name}-extra
%if 0%{?suse_version} > 1500
BuildRequires:  qt6-gui-private-devel
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(libpipewire-0.3)
%else
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
%endif
%if %{with faad}
BuildRequires:  libfaad-devel
%endif

%description
Plugins for the Audacious audio player.

%lang_package

%package extra
Summary:        Extra plugins for Audacious
License:        BSD-2-Clause AND GPL-2.0-or-later AND MIT
Requires:       %{name} = %{version}

%description extra
Extra plugins for the Audacious audio player.

%prep
%autosetup -p1

%build
%meson \
  -Dqt=true     \
%if 0%{?suse_version} > 1500
  -Dqt6=true  \
%else
  -Dqt6=false \
%endif
  -Dgtk=true    \
  -Dgtk3=true   \
%ifarch %{arm} aarch64
  -Dgl-spectrum=false \
%endif
%if %{with faad}
  -Daac=true   \
%else
  -Daac=false  \
%endif
  -Dmpg123=true
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%files
%license COPYING
%{_libdir}/audacious/
%if %{with faad}
%exclude %{_libdir}/audacious/Input/aac-raw.so
%endif
%exclude %{_libdir}/audacious/Output/filewriter.so
%{_datadir}/audacious/

%files lang -f %{name}.lang

%files extra
%if %{with faad}
%{_libdir}/audacious/Input/aac-raw.so
%endif
%{_libdir}/audacious/Output/filewriter.so

%changelog
* Tue Mar  7 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.3:
  * See https://audacious-media-player.org/news/56-audacious-4-3-released
- Add PipeWire, ModPlug and Opus build requirements.
- Add audacious-plugins-fix-qt6-qthotkey.patch: Fix Qt6 support in
  qthotkey.
- Switch to Qt 6 on openSUSE newer than 15.x
- Switch to GTK 3.
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2:
  * New and improved features:
  - Add a built-in dark theme using Qt's Fusion style (default on
    Windows)
  - Add a dark theme-friendly variant of the built-in fallback
    icons, and make both built-in icon sets user-selectable
  - Add partial support for Ogg FLAC streams
  - Preselect the filename of an imported playlist when exporting
    it again
  - Automatically set the title of an imported playlist based on
    the filename
  - Add a Search and Select dialog to the Winamp interface in Qt
    mode
  - Add a Jump to Song dialog to the Winamp interface in Qt mode
  - Add formatter syntax to allow truncating title strings
  * Bugs fixed since 4.1:
  - Fix some fluidsynth settings not working
  - Add checks to prevent Open Containing Folder from being
    abused to open other types of file
  - Fix a crash in the bundled Game_Music_Emu library's SNES
    emulation
  - Fix the Winamp interface not minimizing from the Windows
    taskbar
  - Fix .mkv files being skipped when opening a folder
  - Prevent the Qt interface from popping up multiple error
    dialogs
  * Bugs fixed since 4.2-beta1:
  - Don't switch to FileWriter output when no other outputs are
    available
  - Update for compatibility with FFmpeg 5.0
  - Fix hang when reaching the end of some files using FFmpeg
  - Fix playlist unexpectedly scrolling in Winamp interface
  - Prevent crash in 3rd-party QtPBFImagePlugin when using Winamp
    interface
* Tue Feb 22 2022 Wolfgang Bauer <wbauer@tmo.at>
- Fix build with faad again
* Wed Jan 12 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable gl-spectrum on %%arm and aarch64 to fix build
- Rename non-existent faad option to aac (actual name)
* Thu Jun 24 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Add fix-linking-mpg123.patch, required on Leap 15.2 and 15.3,
  fixes boo#1187525
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.1:
  * New Global Hotkeys plugin for Qt
- Dropped upstream merged 0001-Implement-qthotkey-plugin.patch
* Thu Jul 23 2020 Petr Vorel <pvorel@suse.cz>
- Use %%autosetup -p1
* Wed Jul 15 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.5:
  * See https://audacious-media-player.org/news/50-audacious-4-0-5-released
* Fri Jul 10 2020 Petr Vorel <pvorel@suse.cz>
- Fix Winamp Default skin by removing wrong skin file
  * See https://github.com/audacious-media-player/audacious-plugins/pull/93
* Tue Jun  9 2020 Petr Vorel <pvorel@suse.cz>
- Add missing Qt5X11Extras dependency for qthotkey plugin.
* Wed Jun  3 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.4:
  * See https://audacious-media-player.org/news/49-audacious-4-0-4-released
* Sat May 23 2020 aloisio@gmx.com
- Fix build with faad
* Thu Apr 30 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.3:
  * See https://audacious-media-player.org/news/48-audacious-4-0-3-released
- Rebase 0001-Implement-qthotkey-plugin.patch.
* Sat Apr 25 2020 Petr Vorel <petr.vorel@gmail.com>
- 0001-Implement-qthotkey-plugin.patch: Backport qthotkey from
  commit 9904ac5dfaae18ee1200cfcf64693ee3f33f739a to bring back
  functionality lost in update to version 4.0.
* Wed Apr 15 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.2:
  * No changelog available.
- Remove
  audacious-plugins-qtglspectrum-qt-opengles-workaround.patch:
  fixed upstream.
* Mon Apr  6 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0.1:
  * Seeking in audio files when using the SoX resampler plugin will
    no longer crash the player.
* Sun Mar 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.0:
  * See https://audacious-media-player.org/news/45-audacious-4-0-released
- Add audacious-plugins-qtglspectrum-qt-opengles-workaround.patch:
  Workaround Qt including OpenGLES headers in qtglspectrum
  (commit a51aa5fc).
- Disable building the deprecated GTK UI.
- Build with Meson.
* Wed Dec 26 2018 sor.alexei@meowr.ru
- Update to version 3.10.1:
  * Bug fixes.
- Add a licence to the package.
- Remove the now-useless "resticted" conditional.
* Tue Oct 30 2018 guillaume.gardet@opensuse.org
- Disable glspectrum and qtglspectrum on %%arm and aarch64 as openGL
  is unsupported
* Thu Aug  9 2018 sor.alexei@meowr.ru
- Update to version 3.10:
  * See the audacious package's changelog.
- Remove audacious-plugins-qt-5.10.patch: fixed upstream.
- Switch back to Gtk2 from Gtk3 for the Gtk3 version is gone.
* Sat Jan  6 2018 sor.alexei@meowr.ru
- Add audacious-plugins-qt-5.10.patch: Fix building with Qt 5.10+.
* Sun Oct 29 2017 olaf@aepfle.de
- Remove GTK conditional, it is always enabled and the name is too generic
- Remove stale Qt conditional
* Fri Aug 25 2017 olaf@aepfle.de
- Remove conditionals for lame, qt and mpg123
* Wed Aug 23 2017 aloisio@gmx.com
- Update to version 3.9 (no changelog available)
- Changed source URL
* Mon Jun  5 2017 sor.alexei@meowr.ru
- Don't build with libmodplug as openmpt is only partially
  compatible..
* Thu May 11 2017 sor.alexei@meowr.ru
- Enable building with libmpg123 for newer openSUSE releases even
  outside of Packman.
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * No changelog available.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * No changelog available.
* Fri Sep 23 2016 sor.alexei@meowr.ru
- Update to version 3.8:
  * No changelog available.
- Place /usr/lib64/audacious/Output/filewriter.so in
  audacious-plugins-extra because it can be built with MP3 support.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 3.7.2.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 3.7.1.
* Sun Nov  8 2015 sor.alexei@meowr.ru
- Update to 3.7.
- Enable Qt UI.
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Work with Audacious package version instead of ABI version to
  simplify things a lot.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 3.6.2.
- Enable XEmbed-tray icon plugin for openSUSE 13.2 and older.
* Sat Apr  4 2015 sor.alexei@meowr.ru
- Update to 3.6.1.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 3.6.
* Sun Dec 28 2014 sor.alexei@meowr.ru
- Update to 3.5.2.
- Remove licenses files, complicates without actual need
  (user can find licenses in spec file).
- Simplify regular expression in aud_plugin_api.
* Thu Dec 26 2013 mrdocs@opensuse.org
- Try to fix build - missing soxr, so comment it out for now
* Tue Dec 17 2013 reddwarf@opensuse.org
- Update to 3.4.2
* Fri Mar 29 2013 fisiu@opensuse.org
- Update to 3.3.4:
  * GIO transport plugin is now enabled by default
  * LIRC plugin is back
  * FLAC plugin now supports higher quality files
  * Many bugfixes
- Spec cleanup, use pkgconfig, remove old ifelse statements.
- audacious-plugins-transport-smb subpackage is gone, GIO transport
  plugin can handle smb://
* Sun Aug 19 2012 seife+obs@b1-systems.com
- update to current version 3.2.4
  - disable cdaudio plugin on 12.2+, needs fix for new libcdio
- remove no longer needed -lgmodule linker hack
* Tue May 22 2012 seife+obs@b1-systems.com
- fix build on > 12.1 by adding -lgmodule-2.0 to LIBS
* Fri Dec  9 2011 detlef@links2linux.de
- new upstream version <3.1.1>
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- update to 3.1
* Sun Nov  6 2011 detlef@links2linux.de
- new upstream version <3.0.3>
* Sun Aug 28 2011 detlef@links2linux.de
- new upstream version <3.0.2>
* Sat Aug 13 2011 detlef@links2linux.de
- new upstream version <3.0.1>
* Sat Jul  2 2011 detlef@links2linux.de
- new upstream version <2.5.3>
* Thu Jun 23 2011 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat May 21 2011 detlef@links2linux.de
- new upstream version <2.5.1>
* Sun Apr 17 2011 detlef@links2linux.de
- new upstream version <2.5.0>
* Sun Feb 27 2011 detlef@links2linux.de
- add no libavcodec patch for new ffmpeg
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <2.4.4>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <2.4.3>
* Fri Dec 31 2010 detlef@links2linux.de
- add alsa patch <2.4.2-2>
* Wed Dec  8 2010 detlef@links2linux.de
- new upstream version <2.4.2>
* Wed Sep  8 2010 detlef@links2linux.de
- rebuild with projectM 2.0.1  <2.4.0-5>
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <2.4-rc3>
* Fri Apr  9 2010 detlef@links2linux.de
- new upstream version <2.3>
* Wed Mar 17 2010 detlef@links2linux.de
- enable projectM support
* Wed Dec  9 2009 detlef@links2linux.de
- new upstream version <2.2>
* Wed Jul  8 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.1>
* Fri Jun  5 2009 Manfred.Tremmel@iiv.de
- new upstream version <2.0.1>
* Sun Jul 20 2008 detlef@links2linux.de
- resplit subpackages:
  audacious-plugins contains the core-plugins because package
  managers are stupid ;)
* Wed Jul  9 2008 guru@unixtech.be
- added explicit list of plugins
* Tue Jul  8 2008 guru@unixtech.be
- add AdLib support
* Mon Jul  7 2008 guru@unixtech.be
- build against libmtp-0.3.0
- many fixes/patches
- patches to build on openSUSE 10.2
* Mon May 26 2008 detlef@links2linux.de
- new upstream version <1.5.1>
* Sun Mar 30 2008 detlef@links2linux.de
- disable ss2 for ix86, some old cpus doesn't support sse2
* Sat Mar 15 2008 detlef@links2linux.de
- new upstream version <1.5.0>
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <1.4.5>
* Wed Jan  2 2008 detlef@links2linux.de
- new upstream version <1.4.4>
* Mon Dec 31 2007 detlef@links2linux.de
- new upstream version <1.4.3.2>
* Sat Dec 29 2007 detlef@links2linux.de
- new upstream version <1.4.3>
* Sun Dec 23 2007 detlef@links2linux.de
- new upstream version <1.4.2>
* Fri Nov 23 2007 detlef@links2linux.de
- add support for neon and C64 SID
* Mon Nov 19 2007 detlef@links2linux.de
- new upstream release <1.4.1>
* Tue Nov  6 2007 detlef@links2linux.de
- new upstream release <1.4.0>
* Mon Nov  5 2007 detlef@links2linux.de
- switch to 1.4 on PackMan
- Audacious 1.4 is now complete, and is now recommended over 1.3
* Fri Nov  2 2007 detlef@links2linux.de
- new upstream release <1.4.0-rc1>
* Mon Oct 29 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta4>
* Mon Oct 15 2007 detlef@links2linux.de
- new upstream release <1.4.0-beta3>
* Thu Sep 13 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr4>
* Sun Sep  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr3>
* Thu Aug  9 2007 detlef@links2linux.de
- new upstream release <1.4.0-dr2>
* Mon Jul 23 2007 detlef@links2linux.de
- initial build <1.4.0-dr1>
